==> moodle-1.4.3-pgsql.tgz: moodle/lang/pt_br/error.php <==
<?PHP // $Id$ 
      // error.php - created with Moodle 1.4.2 (2004083120)


$string['coursegroupunknown'] = 'O curso correspondente ao grupo $a no foi definido';
$string['erroronline'] = 'Erro na linha $a';
$string['fieldrequired'] = '\"$a\"  um campo obrigatrio';
$string['filenotfound'] = 'Sinto muito, o arquivo no foi encontrado';
$string['groupalready'] = 'O usurio j participa do grupo $a';
$string['groupunknown'] = 'O grupo $a no  associado ao curso especificado';
$string['invalidfieldname'] = '\"$a\" no  um nome de campo vlido';
$string['missingfield'] = 'O campo \"$a\" est faltando';
$string['modulerequirementsnotmet'] = 'No foi possvel instalar mdulo \"$a->modulename\" ($a->moduleversion). A instalao requer uma verso de Moodle mais recente. Atualmente voc est usando a verso $a->currentmoodle, mas voc precisa da verso $a->requiremoodle.';
$string['notavailable'] = 'Atualmente no  disponvel';
$string['restricteduser'] = 'Sinto muito, mas a sua conta atual, \"$a\" , no tem permisso para fazer isto.';
$string['sessionipnomatch'] = 'Sinto muito, mas parece que o seu nmero de IP mudou desde o seu primeiro login. Esta medida de segurana evita o roubo da sua identidade por crackers enquanto voc estiver utilizando este site. Contate o administrador do site se voc~e precisar de ajuda para resolver este problema.';
$string['unknowncourse'] = 'Curso \"$a\" desconhecido';
$string['usernotaddederror'] = 'Usurio \"$a\" no foi adicionado - erro indefinido';
$string['usernotaddedregistered'] = 'Usurio \"$a\" no foi adicionado - j foi registrado antes';
$string['usernotavailable'] = 'O acesso aos dados deste usurio  reservado.';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/pt_br/error.php <==
<?PHP // $Id$ 
      // error.php - created with Moodle 1.5 + (2005060201)


$string['adminprimarynoedit'] = 'Apenas o administrador principal pode alterar os seus dados';
$string['confirmsesskeybad'] = 'Sinto muito mas o foi possvel confirmar a chave da sua sesso para completar esta ao. Esta medida de segurana evita a execuo de funes importantes em seu nome, causadas por terceiros maliciosos ou por erros acidentais. Controle se a execuo desta funo  intencional.';
$string['coursegroupunknown'] = 'O curso correspondente ao grupo $a no foi definido';
$string['erroronline'] = 'Erro na linha $a';
$string['fieldrequired'] = '\"$a\"  um campo obrigatrio';
$string['filenotfound'] = 'Sinto muito, o arquivo no foi encontrado';
$string['groupalready'] = 'O usurio j participa do grupo $a';
$string['groupunknown'] = 'O grupo $a no  associado ao curso especificado';
$string['invalidfieldname'] = '\"$a\" no  um nome de campo vlido';
$string['missingfield'] = 'O campo \"$a\" est faltando';
$string['modulerequirementsnotmet'] = 'No foi possvel instalar mdulo \"$a->modulename\" ($a->moduleversion). A instalao requer uma verso de Moodle mais recente. Atualmente voc est usando a verso $a->currentmoodle, mas voc precisa da verso $a->requiremoodle.';
$string['notavailable'] = 'Atualmente no  disponvel';
$string['onlyeditown'] = 'Voc pode modificar apenas os seus dados';
$string['processingstops'] = 'Processamento interrompido aqui. Os demais registros foram ignorados.';
$string['restricteduser'] = 'Sinto muito, mas a sua conta atual, \"$a\" , no tem permisso para fazer isto.';
$string['sessionerroruser'] = 'A sua sesso foi interrompida (time out). Por favor faa um novo login.';
$string['sessionipnomatch'] = 'Sinto muito, mas parece que o seu nmero de IP mudou desde o seu primeiro login. Esta medida de segurana evita o roubo da sua identidade por crackers enquanto voc estiver utilizando este site. Contate o administrador do site se voc~e precisar de ajuda para resolver este problema.';
$string['unknowncourse'] = 'Curso \"$a\" desconhecido';
$string['usernotaddederror'] = 'Usurio \"$a\" no foi adicionado - erro indefinido';
$string['usernotaddedregistered'] = 'Usurio \"$a\" no foi adicionado - j foi registrado antes';
$string['usernotavailable'] = 'O acesso aos dados deste usurio  reservado.';

?>
